<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     7.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}

?>
<form class="login" method="post" <?php echo esc_attr( $hidden ) ? 'style="display:none;"' : ''; ?>>
	<?php
	do_action( 'woocommerce_login_form_start' );
	echo esc_attr( $message ) ? wpautop( wptexturize( $message ) ) : ''; // @codingStandardsIgnoreLine
	?>
	<p class="form-row form-row-first">
		<input type="text" class="input-text form-control" placeholder="<?php esc_attr_e( 'Username or email', 'consulting' ); ?>" name="username" id="username" />
	</p>
	<p class="form-row form-row-last">
		<input class="input-text form-control" placeholder="<?php esc_attr_e( 'Password', 'consulting' ); ?>" type="password" name="password" id="password" />
	</p>
	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form' ); ?>

	<p class="form-row">
		<?php wp_nonce_field( 'woocommerce-login' ); ?>
		<input type="submit" class="button" name="login" value="<?php esc_attr_e( 'Login', 'consulting' ); ?>" />
		<input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ); ?>" />
		<label for="rememberme" class="inline">
			<input name="rememberme" type="checkbox" id="rememberme" value="forever" /> <?php esc_html_e( 'Remember me', 'consulting' ); ?>
		</label>
	</p>
	<p class="lost_password">
		<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'consulting' ); ?></a>
	</p>

	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form_end' ); ?>

</form>
